# ===================================================================
#
#  PROZEDUR:  setglobal.sh
#
#  ZWECK   :  Definition globaler Funktionen
#
#  AUFRUF  :  . ./setglobal.sh
#
#  BEMERKUNG:
#
#  AUTOR:     P. Seher
#
#
# =====================================================================

# -------------------------------------------------------------------
# Globale SHELL-Variable
# -------------------------------------------------------------------

MEXREPORTS=$HOME/mexreports;       export MEXREPORTS;  # MEXREPORTS-Wurzelverzeichnis
LOGPATH=$MEXREPORTS/LOGGING;       export LOGPATH;     # Logging-Pfad
JOBPATH=$MEXREPORTS/JOBS;          export JOBPATH;     # Pfad der Jobdateien
PROGPATH=$MEXREPORTS/PROGRAMME;    export PROGPATH;    # Pfad der Prorgamme
DSETPATH=$MEXREPORTS/DATASETS_TRANSIT;     export DSETPATH;    # Pfad der Datasets

ZIP=/usr/bin/minizip;			export ZIP;

# =====================================================================
#  Berichts-MONAT und -JAHR: BMT BJT VJT BM BJ VJ
#
#  !!!Vorsicht!!!
#  ===============
#  Diese Zeitangaben sind in erster Linie fuer monatliche Schnittstellen
#  vorgesehen; sie sind korrekt zwischen U+2 und dem vorletzten Tag(Nacht!)
#  im Monat.
# =====================================================================

let BMT=`date +%m`      # Berichtsmonat bezogen auf den akt. Tag
let BJT=`date +%Y`      # Berichtsjahr  bezogen auf den akt. Tag
let VJT=$BJT-1          # Vorjahr       bezogen auf den akt. Tag

let BM=$BMT-1           # Letzter abgeschl. Monat (eigentlicher Berichtsmonat)
let BJ=$BJT             # Berichtsjahr bezogen auf den letzen abgeschl. Monat
let VJ=$VJT             # Vorjahr      bezogen auf den letzen abgeschl. Monat

if [ $BMT = 1 ]
then
   # -- Jahreswechsel: Im Januar wird noch das Vorjahr betrachtet
   let BM=12
   let BJ=$BJT-1
   let VJ=$BJ-1
fi

export BMT BJT VJT BM BJ VJ


# -------------------------------------------------------------------
# Globale SHELL-Funktionen
# -------------------------------------------------------------------

# fzeit: ------------------------------------------------------------
# -> Zeitstempel
fzeit()
{ date +%H:%M:%S; }


# fdatum: -----------------------------------------------------------
# -> Datum
fdatum()
{ date +%d.%m.%y; }


# flog_step: --------------------------------------------------------
# -> LOGGING-Funktion, Ausgabe auf STDOUT uns in datei steps.log
flog_step()
{
	echo $* | tee -a  $LOGPATH/steps.log
}


# fget_logid: -------------------------------------------------------
#             Logging-ID bestimmen
fget_logid ()
{
	date +${1:-'-'}%d%m%y%H%M%S ;
}


# --------------------------------------------------------
# FUNKTION:     fget_logname
# ZWECK:        Name einer Loggingdatei erstellen
#               Format des Namens: <prefix><datum>.<uhrzeit>.log
#               <prefix><datum><uhrzeit>.log
#
# PARAMETER   : 'laden' oder 'datamart'
# BESCHREIBUNG:
#               Das Format des erstellten  Namens ist:
#
#               <parameter><datum>.<uhrzeit>.log
# --------------------------------------------------------
fget_logname()
{
	echo $1`date +%d%m%y.%H%M%S`.log ;
}
typeset -xf fget_logname;


# --------------------------------------------------------
# FUNKTION:     fdatamart
# ZWECK:        Aufruf der Datamarterstellung von EUROVIS mit einheitlicher
#               ,laufspezifischer LOG-Datei.
#
# PARAMETER   : Parameter von datamart.sh  werden durchgereicht
# --------------------------------------------------------
fdatamart()
{
if [ "$1" = '-info' ]
   then
       # Nur Bildschirmausgabe
       $JOBPATH/datamart.sh $*
       return $?
   else

       DATAMART_LOG=`fget_logname datamart`; export DATAMART_LOG;
       $JOBPATH/datamart.sh $*  2>&1  > $LOGPATH/$DATAMART_LOG;

   fi
}
typeset -xf fdatamart;


# ----------------------------------------------------------------------------------
# FUNKTION:     fsh_step
# ZWECK:        Aufruf einer Shell-Prozedur mit Integration ins zentrale Monitoring.
#
# PARAMETER   :  fsh_step <sh-prog> <logname> <jobname>
# BESCHREIBUNG:
#               <sh-prog>: Name der Shell-Prozedur
#
#               <logname>: Standardausgabe und Fehlerkanal werden
#                          werden in diese Datei umgeleitet.
#
#                          Wird '-' als Name fr die Logdatei angegeben,
#                          erfolgt keine Umleitung.
#
#               <jobname>: Name unter dem der Vorgang im Monitoring erscheint.
#
#                          Wird '-' als <jobname> verwendet, wird kein Monitorsatz
#                          erstellt, sondern das Ergebnis auf die Standard-Ausgabe
#                          geschrieben. Dies ist z.B sinnvoll, wenn ein Programm
#                          mehrfach in "Scheiben" aufgerufen wird und dabei nur das
#                          Gesamtergebnis interessiert. Anderenfalls wren im Monitor
#                          z.B. entsprechende 50 Scheibeneintrge in der Tagesbersicht.
#
# ----------------------------------------------------------------------------------
fsh_step()
{
if [ $# != 3 ]
then
	echo "FEHLER: Zu wenig Parameter fr den Funktionsaufruf fsh_step()"
  return 11
fi

typeset SHPROG=$1
typeset SHLOG=$2
typeset JOBNAME=$3

typeset START_DATE=`fdatum`;
typeset START_TIME=`fzeit`;
typeset RC_fsh=0;

if [ "X$SHLOG" = "X-" ]
then
    echo  Programm $SHPROG starten  ohne spezielle Loggingdatei
    $SHPROG
    RC_fsh=$?
else
    # - 'Alte' LOG-Datei sichern
    if test -s $SHLOG
      then
       cat $SHLOG >> $SHLOG.old
      fi

    echo  Programm $SHPROG 2>&1 > $SHLOG starten
		echo "Programm $SHPROG starten..." 2>&1
    #$SHPROG 2>&1 |tee -ai $SHLOG !! RC von $SHPROG geht verloren
    $SHPROG 2>&1 1>$SHLOG
    RC_fsh=$?
    # Protokoll zusaetzlich auf die Standardausgabe 
    cat $SHLOG
fi

typeset END_TIME=`fzeit`;

# - Ergebnis Protokollieren
if [ "X$JOBNAME" = "X-" ]
then
         echo ${LOGGING_ID:-`fget_logid`}';'$JOBNAME';'$START_DATE';'$START_TIME';'$END_TIME';'$RC_fsh';'`basename $SHLOG`';'
else
    flog_step ${LOGGING_ID:-`fget_logid`}';'$JOBNAME';'$START_DATE';'$START_TIME';'$END_TIME';'$RC_fsh';'`basename $SHLOG`';'
fi

return $RC_fsh
}

